@@ -151,7 +151,7 @@ fill_with_na <- na_insert
 r_cut_breaks <- function(x, n){
   check_length(n, 1)
   stopifnot(n >= 2)
-  breaks <- get_breaks(x, n, pretty = FALSE)
+  breaks <- get_breaks(x, n, pretty = FALSE, expand_min = FALSE, expand_max = FALSE)
   adj <- diff(range(breaks)) * 0.001
   breaks[1] <- breaks[1] - adj
   breaks[length(breaks)] <- breaks[length(breaks)] + adj
@@ -210,22 +210,49 @@ combine_factors <- function(...){
 }
 
 # A very fast 1-D array frequency table
-cheapr_table <- function(x, names = TRUE, order = FALSE, na_exclude = FALSE){
-  if (is.factor(x)){
-    if (na_exclude){
-      f <- levels_drop_na(x)
-    } else if (any_na(x)){
-      f <- levels_add_na(x)
+cheapr_table <- function(..., names = TRUE, order = FALSE, na_exclude = FALSE,
+                         classed = FALSE){
+
+  vecs <- list(...)
+
+  to_factor <- function(x, na.excl){
+    if (is.factor(x)){
+      if (na_exclude){
+        levels_drop_na(x)
+      } else if (any_na(x)){
+        levels_add_na(x)
+      } else {
+        x
+      }
     } else {
-      f <- x
+      factor_(x, order = order, na_exclude = na_exclude)
+    }
+  }
+
+  factors <- lapply(vecs, to_factor, na_exclude)
+
+  if (length(factors) == 1){
+    f <- factors[[1L]]
+    lvls <- attr(f, "levels")
+    out <- tabulate(f, nbins = length(lvls))
+    if (names){
+      dim_names <- list(lvls)
+      names(dim_names) <- names(vecs)
+      names(out) <- lvls
+    } else {
+      dim_names <- NULL
+    }
+    if (classed){
+      out <- array(out, length(out), dim_names)
+      class(out) <- "table"
     }
   } else {
-    f <- factor_(x, order = order, na_exclude = na_exclude)
-  }
-  lvls <- attr(f, "levels")
-  out <- tabulate(f, nbins = length(lvls))
-  if (names){
-    names(out) <- lvls
+    out <- do.call(collapse::qtab, c(factors, list(dnn = NULL)), envir = parent.frame())
+    if (!classed){
+      cpp_set_rm_attr(out, "class")
+      cpp_set_rm_attr(out, "sorted")
+      cpp_set_rm_attr(out, "weighted")
+    }
   }
   out
 }
@@ -244,6 +271,11 @@ df_add_cols <- function(data, cols){
   out
 }
 
+# unevaluated expression list
+exprs <- function(...){
+  as.list(substitute(alist(...)))[-1]
+}
+
 # Just a wrapper with a cheaper alternative to `c.factor()`
 # cheapr_c <- function(..., .check = TRUE){
 #   dots <- list(...)
